#
## Author: Ian Mitchell / Middlesex University
# NO WARRANTY
# 1.1 Neuron pyNN Tutorial
from pyNN.utility.plotting import Figure, Panel
from pyNN.utility import get_script_args, init_logging, normalized_filename
simulator_name = get_script_args(1)[0]  
exec("from pyNN.%s import *" % simulator_name)
#CONSTANTS
POPULATION_SIZE = 10
SIMULATION_TIME = 500
WEIGHT		= 5.0
DELAY		= 10.0
#plot spikes for population, pop, in file, filename
def plotSpikes(pop,filename):
	data=pop.get_data().segments[0]
	Figure(Panel(data.spiketrains, xlabel="time (ms)", xticks=True)).save(filename)
#create setup
setup(timestep=DELAY, min_delay=DELAY, max_delay=DELAY+99)
#create cell parameters - more explanation later
cell_params = {'tau_refrac' : 5.0,'v_rest' : -65.0,'v_thresh' : -51.0,'tau_syn_E':2.0,
		'tau_syn_I': 5.0,'v_reset': -70.0,'i_offset': 0.0,'cm': 0.1}
#create a spike array
spikeTimes = [[i for i in range(1,10,2)]]	
#create a neuron
neuron_1 = Population(1, SpikeSourceArray,{'spike_times': spikeTimes})
#create a population of neurons
neuron_2 = Population(POPULATION_SIZE, IF_curr_exp, cell_params, label='neuron_2')
#connection
injectionConnection = [(0, 0, WEIGHT, DELAY)]
#Projections
Projection(neuron_1,neuron_2,FromListConnector(injectionConnection),StaticSynapse(weight=WEIGHT))
Projection(neuron_2,neuron_2,AllToAllConnector(allow_self_connections=False),StaticSynapse(weight=WEIGHT))
#record
neuron_2.record(['spikes'])
#run simulation
run(SIMULATION_TIME)
#get spike activity
plotSpikes( neuron_2, 'ex1_spikes.png' )
end()
