#
## Author: Ian Mitchell / Middlesex University
# NO WARRANTY
# 1.1 Neuron pyNN Tutorial
from pyNN.utility.plotting import Figure, Panel
from pyNN.utility import get_script_args, init_logging, normalized_filename
simulator_name = get_script_args(1)[0]  
exec("from pyNN.%s import *" % simulator_name)
#CONSTANTS
POPULATION_SIZE = 10
SIMULATION_TIME = 100
WEIGHT		= 5.0
DELAY		= 5.0
#plot spikes for population, pop, in file, filename
def plotall(pop1,pop2):
	seg1 = pop1.get_data().segments[0]
	seg2 = pop2.get_data().segments[0]
	filename="results.png"
	Figure(Panel(seg1.spiketrains, xlabel="time (ms)", xticks=True),
		Panel(seg2.spiketrains, xticks=True), title="Activity of FSA").save(filename)
setup(timestep=DELAY, min_delay=DELAY, max_delay=DELAY+99)
cell_params = {'tau_refrac' : 5.0,'v_rest' : -65.0,'v_thresh' : -51.0,'tau_syn_E':2.0,
		'tau_syn_I': 5.0,'v_reset': -70.0,'i_offset': 0.0,'cm': 0.1}
#create a spike array
spikeTimes = [[i for i in range(1,10,2)]]	
#create a neuron
pop_0 = Population(1, SpikeSourceArray,{'spike_times': spikeTimes})
pop_3 = Population(1,IF_curr_exp,cell_params)
#create a population of neurons
pop_1 = Population(POPULATION_SIZE, IF_curr_exp, cell_params)
pop_2 = Population(POPULATION_SIZE, IF_curr_exp, cell_params)
injectionConnection = [(0, 0, WEIGHT, DELAY)]
connectors3 = connectors4 = []
w=-10.0*WEIGHT
for i in range(0,POPULATION_SIZE,1):
	connectors4=connectors4+[(0,i,w,DELAY)]
	connectors3=connectors3+[(i,0,WEIGHT,DELAY)]
Projection(pop_0,pop_1,FromListConnector(injectionConnection),StaticSynapse(weight=WEIGHT))
Projection(pop_1,pop_1,AllToAllConnector(allow_self_connections=False),StaticSynapse(weight=WEIGHT))
Projection(pop_2,pop_2,AllToAllConnector(allow_self_connections=False),StaticSynapse(weight=WEIGHT))
Projection(pop_1,pop_2,AllToAllConnector(),StaticSynapse(weight=WEIGHT)) #excitatory
Projection(pop_2,pop_3,FromListConnector(connectors3)) #excitatory
#Projection(pop_3,pop_2,FromListConnector(connectors4)) #inhibitory
#Projection(pop_3,pop_1,FromListConnector(connectors4)) #inhibitory
pop_1.record(['spikes']) 
pop_2.record(['spikes'])
#run simulation
run(SIMULATION_TIME)
plotall(pop_1,pop_2)
