#
## Author: Ian Mitchell / Middlesex University
# NO WARRANTY
# 1.1 Neuron pyNN Tutorial
from pyNN.utility.plotting import Figure, Panel
from pyNN.utility import get_script_args, init_logging, normalized_filename
simulator_name = get_script_args(1)[0]  
exec("from pyNN.%s import *" % simulator_name)
#CONSTANTS
POPULATION_SIZE = 10
SIMULATION_TIME = 1000
INTERVAL	= 200
WEIGHT		= 1.
DELAY		= 5.0
#plot spikes for population, pop, in file, filename
def plotall(pop1,pop2):
	seg1 = pop1.get_data().segments[0]
	seg2 = pop2.get_data().segments[0]
	filename="results_ex3.png"
	Figure(Panel(seg1.spiketrains, xlabel="time (ms)", xticks=True),
		Panel(seg2.spiketrains, xticks=True), title="Activity of FSA").save(filename)
setup(timestep=DELAY, min_delay=DELAY, max_delay=DELAY+99)
cell_params = {'tau_refrac' : 5.0,'v_rest' : -65.0,'v_thresh' : -51.0,'tau_syn_E':2.0,
		'tau_syn_I': 5.0,'v_reset': -70.0,'i_offset': 0.0,'cm': 0.1}
#create a spike array
spikeTimes1 = [[i for i in range(1,SIMULATION_TIME,INTERVAL)]]
spikeTimes2 =[[i for i in range(1,SIMULATION_TIME,2*INTERVAL)]]
#create a neuron
card = Population(1, SpikeSourceArray,{'spike_times': spikeTimes1})#card
mass = Population(1, SpikeSourceArray,{'spike_times': spikeTimes2})#enter
closeOut = Population(1,IF_curr_exp,cell_params) #close
openOut = Population(1,IF_curr_exp,cell_params) #open
#create a population of neurons
pop=[] #states
for i in range(0,2,1):
	pop=pop+[Population(POPULATION_SIZE, IF_curr_exp, cell_params)]
	Projection(pop[i],pop[i],AllToAllConnector(allow_self_connections=False),StaticSynapse(weight=WEIGHT))
injectionConnection = [(0, 0, 0.5*WEIGHT, DELAY)]
connectorIn = connectorEx = connectorIn1 = connectorEx1 = []
w=-10.0*WEIGHT
for i in range(0,POPULATION_SIZE,1):
	connectorIn=connectorIn+[(0,i,w,DELAY)]
	connectorEx1=connectorEx1+[(0,i,WEIGHT,DELAY)]
	connectorEx=connectorEx+[(i,0,WEIGHT,DELAY)]
	connectorIn1=connectorIn1+[(i,0,w,DELAY)]
Projection(card,pop[0],FromListConnector(injectionConnection),StaticSynapse(weight=WEIGHT))
Projection(mass,pop[0],FromListConnector(injectionConnection),StaticSynapse(weight=WEIGHT))
Projection(pop[0],pop[1],AllToAllConnector(),StaticSynapse(weight=WEIGHT))
Projection(pop[1],pop[0],AllToAllConnector(),StaticSynapse(weight=WEIGHT))
Projection(pop[1],openOut,FromListConnector(connectorEx),StaticSynapse(weight=WEIGHT))
Projection(openOut,pop[0],FromListConnector(connectorIn),StaticSynapse(weight=WEIGHT))
Projection(pop[0],closeOut,FromListConnector(connectorEx),StaticSynapse(weight=WEIGHT))
Projection(closeOut,pop[1],FromListConnector(connectorIn),StaticSynapse(weight=WEIGHT))
pop[0].record(['spikes']) 
pop[1].record(['spikes'])
#run simulation
run(SIMULATION_TIME)
plotall(pop[0],pop[1])
